A (simulated) dataset containing information about 4 geographical areas (about 120 dwellings each) sampled for the labour force survey.
lfs_samp_areaA data frame with 4 observations and 3 variables:
identifier of the area
total annual income of the area in thousand euros (from income registry)
first-order inclusion probability of the area (proportional to the number of dwellings in the area)
define_variance_wrapper, lfs_samp_dwel, lfs_samp_ind